import { Workspace } from '../../../types/index';
/**
 * Represents a Module entry per LWC component
 */
export interface ModuleMapEntry {
    /**
     * Owner module in format like <namespace>/<component-name>.
     * Example for internal modules, "lightning/global".
     * Example for custom modules, "c/myComponent".
     */
    ownerModuleId: string;
    /**
     * Various parts of the module.
     * For example:
     * {
     *      "c/myComponent/myComponent.js": "workspace/ui-module/my-project/force-app/main/default/lwc/myComponent/myComponent.js",
     *      "c/myComponent/myComponent.html": "workspace/ui-module/my-project/force-app/main/default/lwc/myComponent/myComponent.html",
     *      "c/myComponent/util/util.js": "workspace/ui-module/my-project/force-app/main/default/lwc/myComponent/util/util.js",
     * }
     */
    moduleParts: {
        [key: string]: string;
    };
}
/**
 * An interface to define a workspace scanner that will build a map of modules and its assets in a given workspace.
 * It accepts a set of directories and returns a map of Module Ids to file paths.
 */
export interface WorkspaceScanner {
    /**
     * Defines the type of workspace.
     */
    workspace: Workspace;
    /**
     * The LWC modules directories contained in this workspace.
     * In internal workspace type, the values will be the ["core/ui-xx-modules"] folders.
     * In Salesforce CLI workspace type, the value will be ["workspace/ui-module/my-project/force-app/main/default/"] folder.
     */
    modulesPaths: string[];
    /**
     * Get information about LWC modules contained in the workspace.
     */
    getModulesMap(): ModuleMapEntry[];
}
export declare abstract class BaseWorkspaceScanner implements WorkspaceScanner {
    workspace: Workspace;
    modulesPaths: string[];
    constructor(workspace: Workspace, modulesPaths: string[]);
    /**
     * Get information about LWC modules contained in the workspace.
     */
    getModulesMap(): ModuleMapEntry[];
    abstract getNamespace(moduleDir: string): string;
    abstract findModuleDirs(): string[];
    scanAModule(moduleDir: string): ModuleMapEntry | undefined;
}
