/// <reference types="node" />
import type { ClientTarget } from '@lwc/lwc-dev-server-types';
/**
 * Define the type of workspace.
 * Internal is for salesforce internal developers.
 * SfCli is for the Salesforce CLI project setup.
 */
export declare enum Workspace {
    Internal = "internal",
    SfCli = "SalesforceCLI",
    Mrt = "mrt"
}
/**
 * Logging level in decreasing order of severity and increasing order of noise.
 */
export declare enum LogLevel {
    silent = 0,
    error = 1,
    warn = 2,
    info = 3,
    debug = 4,
    verbose = 5
}
/**
 * Config for HTTPS server
 * Technically all the supported fields that `require('ndoe:https').createServer` accepts can be passed here,
 * https://nodejs.org/api/https.html#httpscreateserveroptions-requestlistener
 *
 * but we handpicked the ones that are most used here.
 * Usually users either provide a cert and a key or pfx and a passphrase
 */
export type HttpsConfig = Partial<{
    cert: string;
    key: string;
    pfx: Buffer;
    passphrase: string;
}>;
/**
 * Interface representing the LWC Local Development server config.
 */
export interface ServerConfig {
    /**
     * The root directory for the project, config files and path will be referenced as relative to this directory
     * For internal developers: core home
     * For Salesforce CLI customers: The Salesforce DX Project dir
     */
    rootDir: string;
    /** Port at which the web socket will communicating from. */
    port: number;
    /** Websocket protocol to use */
    protocol: string;
    /** Host where the dev server is running. Will be used to send information to the client.  */
    host: string;
    /**
     * Component paths to watch
     * For SF CLI: force-app/main/default
     */
    paths: string[];
    /** Container targets to bundle modules for. */
    targets: ClientTarget[];
    workspace: Workspace;
    logLevel: LogLevel;
    https?: HttpsConfig;
}
